@@ -15,8 +15,13 @@ class ByteContentProvider(ContentProvider):
 
     """
 
-    def __init__(self, content: bytes, file_path: Optional[str] = None) -> None:
-        super().__init__(file_path if file_path is not None else "")
+    def __init__(
+            self,  #
+            content: bytes,  #
+            file_path: Optional[str] = None,  #
+            file_type: Optional[str] = None,  #
+            info: Optional[str] = None) -> None:
+        super().__init__(file_path=file_path, file_type=file_type, info=info)
         self.lines = Util.decode_bytes(content)
 
     def get_analysis_target(self) -> List[AnalysisTarget]:
