@@ -1,4 +1,4 @@
-from typing import Dict, List, Optional, Tuple
+from typing import Dict, List, Optional
 
 from regex import regex
 
@@ -21,7 +21,7 @@ class Rule:
         rule_type: RuleType used for this rule
         severity: critical/high/medium/low
         filters: List of Filter objects that can be used to filters False detections based on rules
-        patterns: regular expressions that can be used for detection
+        patterns: Regular expressions that can be used for detection
         pattern_type: single_pattern/multi_pattern/pem_key_pattern. single_pattern for simple single line credentials
           multi_pattern for credentials span for rew lines. pem_key_pattern for PEM like credentials
         use_ml: Should ML work on this credential or not. If not prediction based on regular expression and filter only
@@ -40,11 +40,14 @@ class Rule:
         self.config = config
         self._assert_all_rule_fields(rule_template)
         self.rule_name: Optional[str] = rule_template["name"]
-        self.rule_type: Optional[RuleType] = getattr(RuleType, rule_template["type"].upper(), None)
+        _rule_template_type = rule_template["type"]
+        self.rule_type: Optional[RuleType] = getattr(RuleType, _rule_template_type.upper(), None)
+        if self.rule_type is None:
+            raise ValueError(f"Malformed rule config file. Rule type '{_rule_template_type}' is invalid.")
         self.severity: Severity = rule_template["severity"]
         self.filters: List[Filter] = rule_template.get("filter_type")
-        self.patterns: List[regex.Pattern] = (rule_template["type"], rule_template["values"])
-        self.pattern_type: Optional[str] = (rule_template["type"], rule_template["values"])
+        self.patterns: List[regex.Pattern] = Rule._get_patterns(self.rule_type, rule_template["values"])
+        self.pattern_type: str = Rule._get_pattern_type(self.rule_type, len(self.patterns))
         self.use_ml: bool = rule_template["use_ml"]
         self.validations: List[Validation] = rule_template.get("validations")
         self.required_substrings: List[str] = [s.lower() for s in rule_template.get("required_substrings", [""])]
@@ -52,37 +55,45 @@ class Rule:
 
     @property
     def rule_name(self) -> str:
+        """rule_name getter"""
         return self.__rule_name
 
     @rule_name.setter
     def rule_name(self, rule_name: str) -> None:
+        """rule_name setter"""
         self.__rule_name = rule_name
 
     @property
     def rule_type(self) -> RuleType:
+        """rule_type getter"""
         return self.__rule_type
 
     @rule_type.setter
     def rule_type(self, rule_type: RuleType) -> None:
+        """rule_type getter"""
         self.__rule_type = rule_type
 
     @property
     def severity(self) -> Severity:
+        """severity getter"""
         return self.__severity
 
     @severity.setter
     def severity(self, severity: str) -> None:
-        severity_obj = getattr(Severity, severity.upper(), None)
+        """severity setter"""
+        severity_obj: Severity = getattr(Severity, severity.upper(), None)
         if severity_obj is None:
             raise ValueError(f'Malformed rule config file. Rule severity "{severity}" is invalid.')
         self.__severity = severity_obj
 
     @property
     def filters(self) -> List[Filter]:
+        """filters getter"""
         return self.__filters
 
     @filters.setter
     def filters(self, filter_type: str) -> None:
+        """filters setter"""
         if filter_type == "" or filter_type is None:
             self.__filters = []
         else:
@@ -91,13 +102,9 @@ class Rule:
                 raise ValueError(f'Malformed rule config file. Rule filter_type "{filter_type}" is invalid.')
             self.__filters = filter_group(self.config).filters
 
-    @property
-    def patterns(self) -> List[regex.Pattern]:
-        return self.__patterns
-
-    @patterns.setter
-    def patterns(self, args: Tuple[str, List[str]]) -> None:
-        """Set pattern value for rule object.
+    @staticmethod
+    def _get_patterns(_rule_type: RuleType, _values: List[str]) -> List[regex.Pattern]:
+        """Get pattern values for rule object.
 
         Set the pattern value attribute of the rule object based on the passed values.
         So, if the received rule type corresponds to the RuleType.KEYWORD type,
@@ -107,27 +114,34 @@ class Rule:
         assigned the compile regex ov received value
 
         Args:
-            args: Tuple of rule type and regular expressions
+            _rule_type: type of rule
+            _values: regular expressions
 
         """
-        rule_type_str, values = args
-        self.__patterns = []
-        if self.rule_type is None:
-            raise ValueError(f'Malformed rule config file. Rule type "{rule_type_str}" is invalid.')
-        if self.rule_type == RuleType.KEYWORD:
-            for value in values:
-                self.__patterns.append(Util.get_keyword_pattern(value))
-        elif self.rule_type in (RuleType.PATTERN, RuleType.PEM_KEY):
-            for value in values:
-                self.__patterns.append(regex.compile(value))
+        _patterns = []
+        if RuleType.KEYWORD == _rule_type:
+            for value in _values:
+                _patterns.append(Util.get_keyword_pattern(value))
+        elif _rule_type in (RuleType.PATTERN, RuleType.PEM_KEY):
+            for value in _values:
+                _patterns.append(regex.compile(value))
+        else:
+            raise ValueError(f"Malformed rule config file. Rule type '{_rule_type}' is invalid.")
+        return _patterns
 
     @property
-    def pattern_type(self) -> str:
-        return self.__pattern_type
+    def patterns(self) -> List[regex.Pattern]:
+        """patterns getter"""
+        return self.__patterns
 
-    @pattern_type.setter
-    def pattern_type(self, args: Tuple[str, List[str]]) -> None:
-        """Set pattern type for rule object.
+    @patterns.setter
+    def patterns(self, _patterns: List[regex.Pattern]) -> None:
+        """patterns setter"""
+        self.__patterns = _patterns
+
+    @staticmethod
+    def _get_pattern_type(_rule_type: RuleType, _values_len: int) -> str:
+        """Detect pattern type for rule object.
 
         Set the pattern_type attribute of the rule object based on the passed values.
         So, if the received rule type corresponds to the RuleType.PEM_KEY type,
@@ -136,32 +150,46 @@ class Rule:
         and for rules with more than one value set "multi_pattern" type
 
         Args:
-            args: Tuple of rule type and regular expressions
+            _rule_type: rule type
+            _values_len: length of values with expressions
 
         """
-        rule_type_str, values = args
-        self.__pattern_type = None
-        if self.rule_type is None:
-            raise ValueError(f'Malformed rule config file. Rule type "{rule_type_str}" is invalid.')
-        if self.rule_type == RuleType.PEM_KEY:
-            self.__pattern_type = self.PEM_KEY_PATTERN
-        elif len(values) == 1:
-            self.__pattern_type = self.SINGLE_PATTERN
-        elif len(values) > 1:
-            self.__pattern_type = self.MULTI_PATTERN
+        _pattern_type: Optional[str] = None
+        if RuleType.PEM_KEY == _rule_type:
+            _pattern_type = Rule.PEM_KEY_PATTERN
+        elif 1 == _values_len:
+            _pattern_type = Rule.SINGLE_PATTERN
+        elif 1 < _values_len:
+            _pattern_type = Rule.MULTI_PATTERN
+        else:
+            raise ValueError(f"Malformed rule config file. Rule type '{_rule_type}' or '{_values_len}' are invalid.")
+        return _pattern_type
+
+    @property
+    def pattern_type(self) -> str:
+        """pattern_type getter"""
+        return self.__pattern_type
+
+    @pattern_type.setter
+    def pattern_type(self, _pattern_type: str) -> None:
+        """pattern_type setter"""
+        self.__pattern_type = _pattern_type
 
     @property
     def use_ml(self) -> bool:
+        """use_ml getter"""
         return self.__use_ml
 
     @use_ml.setter
     def use_ml(self, use_ml: bool) -> None:
+        """use_ml setter"""
         if not isinstance(use_ml, bool):
             raise ValueError('Malformed rule config file. Field "use_ml" should have a boolean value.')
         self.__use_ml = use_ml
 
     @property
     def validations(self) -> List[Validation]:
+        """validations getter"""
         return self.__validations
 
     @validations.setter
@@ -203,16 +231,20 @@ class Rule:
 
     @property
     def required_substrings(self) -> List[str]:
+        """required_substrings getter"""
         return self.__required_substrings
 
     @required_substrings.setter
     def required_substrings(self, required_substrings: List[str]) -> None:
+        """required_substrings setter"""
         self.__required_substrings = required_substrings
 
     @property
     def min_line_len(self) -> int:
+        """min_line_len getter"""
         return self.__min_line_len
 
     @min_line_len.setter
     def min_line_len(self, min_line_len: int) -> None:
+        """min_line_len setter"""
         self.__min_line_len = min_line_len
